library(ggplot2)

#This R script generates the files to perform a range sweep across multiple dimensions of variables on VENSIM
# It partitions the sweep so each run is of a manageable size.
# Run results will need to be recombined once all are done.
# It utilizes the internal run CMD funcationality of VENSIM.
# It is hand tweaked to generate the needed runs.

setwd("..\\RUNS")
workingDir<-getwd()
getwd()


#####################################
#Generate input variable ranges used to generate the monte carlo runs
#
# DelaysSet is used currently to partion the runs to 
#DELAYTIME<-seq(1,30,by=2)
delaySet<-c(1, 3,5,10, 20, 30)
Efficacy <- seq(0,1,by=0.2)
PBC<- seq(0,1,by=0.2)
PSN<- seq(0,1,by=0.2)
FORGET <- seq(0.5,4,by=0.5)
#####################################################################
# 0 no threshold, 1 threshold(EFFECTIVELY ONLY POSITIVE EVENTS)  
#
#ImplementThreshold<-c(0,1)
ImplementThreshold<-c(0)
#TRANSFORMSWITCH<-seq(0,2,by=1)
TRANSFORMSWITCH<-0
# Add emissions Switch
EmissionSwitch<-c(2,6)
###################################
# Setup Vensim CMD file
logFile = "VenSimRun.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bBase2017Su1.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
  workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowLogT0",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowLogT0",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity Control File
  RandomSeed <- sample(1:10000000, 1)
  cat(paste("200,F, ",RandomSeed," , ",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")
}
#
#
TRANSFORMSWITCH<-1
ImplementThreshold<-c(0)
# Setup Vensim CMD file
logFile = "VenSimWindowCubicT0.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bAltAmodEventAnal1025b.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
    workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowCubT0",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowCubT0",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity COntrol File
  cat(paste("200,F,1234,",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")
}
#
#
TRANSFORMSWITCH<-2
ImplementThreshold<-c(0)
# Setup Vensim CMD file
logFile = "VenSimWindowLinearT0.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bAltAmodEventAnal1025b.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
  workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowLinT0",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowLinT0",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity COntrol File
  cat(paste("200,F,1234,",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")
  
  
}
#
#
####################################3
# 0 no threshold, 1 threshold(EFFECTIVELY ONLY POSITIVE EVENTS)  
#
TRANSFORMSWITCH<-0
ImplementThreshold<-c(1)
# Setup Vensim CMD file
logFile = "VenSimWindowLogisticT1.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bAltAmodEventAnal1025b.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
  workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowLogT1",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowLogT1",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity COntrol File
  cat(paste("200,F,1234,",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")
}
#
#
TRANSFORMSWITCH<-1
ImplementThreshold<-c(1)
# Setup Vensim CMD file
logFile = "VenSimWindowCubicT1.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bAltAmodEventAnal1025b.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
  workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowCubT1",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowCubT1",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity COntrol File
  cat(paste("200,F,1234,",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")  
}
#
#
TRANSFORMSWITCH<-2
ImplementThreshold<-c(1)
# Setup Vensim CMD file
logFile = "VenSimWindowLinearT1.cmd"
cat("SPECIAL>NOINTERACTION", file=logFile, append=FALSE, sep = "\n")
cat("SPECIAL>LOADMODEL|PACEv6bAltAmodEventAnal1025b.mdl", file=logFile, append=TRUE, sep = "\n")
cat("!", file=logFile, append=TRUE, sep = "\n")

for (delayValue in delaySet) {
  #forgetValue<-0.5
  #FORGET <- seq(forgetStart,forgetEnd,by=0.5)
  DELAY <-delayValue
  dataGrid <- expand.grid(Efficacy,PBC,PSN,FORGET,DELAY,TRANSFORMSWITCH,ImplementThreshold,EmissionSwitch)
  names(dataGrid)<-c('Efficacy','PBC','PSN','Forget Factor','WindowAvgTime','TransformSwitch','ImplementThreshold','Switch Emission effect')
  workingDir<-getwd()
  baseOutputName<-paste("SenGridWindowLinT1",formatC(as.integer(delayValue*100), width=4, flag="0"),sep="")
  write.table(dataGrid, paste(workingDir,"/SenGridWindowLinT1",formatC(as.integer(delayValue*100), width=4, flag="0"),".txt",sep=""), sep="\t", row.names=FALSE,quote=FALSE)
  runName<-paste(baseOutputName,".vdf",sep="")
  senName<-paste(baseOutputName,".vsc",sep="")
  outName<-paste(baseOutputName,".tab",sep="")
  cat("!", file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>RUNNAME|",runName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSSAVELIST|VaryForget.lst",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("SIMULATE>SENSITIVITY|",senName,sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>RUN_SENSITIVITY|o",sep=""), file=logFile, append=TRUE, sep = "\n")
  cat(paste("MENU>SENS2TAB|",runName,"|",outName,"|*!|0",sep=""), file=logFile, append=TRUE, sep = "\n")
  #
  # generate Sensitivity COntrol File
  cat(paste("200,F,1234,",baseOutputName,".txt",",0",sep=""), file=senName, append=FALSE, sep = "\n")
  
  
}